==> qtjambi-remoteobjects-6.5.0-sources.jar: io/qt/remoteobjects/QtROServerIoDevice.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QtROServerIoDevice</p>
 */
public abstract class QtROServerIoDevice extends io.qt.remoteobjects.QtROIoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROServerIoDevice.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QtROServerIoDevice {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QtROServerIoDevice(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROServerIoDevice() {
        this((io.qt.core.QObject)null);
    }
    
    public QtROServerIoDevice(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROServerIoDevice instance, io.qt.core.QObject parent);
    
    @QtUninvokable
    protected java.lang.@NonNull String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QtROServerIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QtROServerIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QtROServerIoDevice instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-remoteobjects-6.5.2-sources.jar: io/qt/remoteobjects/QtROServerIoDevice.java <==
package io.qt.remoteobjects;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QtROServerIoDevice</code></p>
 */
public abstract class QtROServerIoDevice extends io.qt.remoteobjects.QtROIoDeviceBase
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QtROServerIoDevice.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QtROServerIoDevice {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public io.qt.core.@Nullable QIODevice connection(){
            return connection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native io.qt.core.QIODevice connection_native_constfct(long __this__nativeId);
        
        
        @Override
        @QtUninvokable
        protected void doClose(){
            doClose_native(QtJambi_LibraryUtilities.internal.nativeId(this));
        }
        @QtUninvokable
        private native void doClose_native(long __this__nativeId);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QtROServerIoDevice(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QtROServerIoDevice() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <code>QtROServerIoDevice::<wbr>QtROServerIoDevice(QObject*)</code></p>
     */
    public QtROServerIoDevice(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QtROServerIoDevice instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <code>QtROIoDeviceBase::<wbr>deviceType()const</code></p>
     */
    @QtUninvokable
    protected java.lang.@NonNull String deviceType(){
        return deviceType_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String deviceType_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QtROServerIoDevice(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QtROServerIoDevice(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QtROServerIoDevice instance, QDeclarativeConstructor constructor);
    
}
